<?php

namespace Shopping\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Shipping\Models\Pincode;

class PincodePolicy
{

    /**
     * Determine if the given user can view the pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function view(UserPolicy $user, Pincode $pincode)
    {
        if ($user->canDo('shipping.pincode.view') && $user->isAdmin()) {
            return true;
        }

        return $pincode->user_id == user_id() && $pincode->user_type == user_type();
    }

    /**
     * Determine if the given user can create a pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.pincode.create');
    }

    /**
     * Determine if the given user can update the given pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function update(UserPolicy $user, Pincode $pincode)
    {
        if ($user->canDo('shipping.pincode.edit') && $user->isAdmin()) {
            return true;
        }

        return $pincode->user_id == user_id() && $pincode->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Pincode $pincode)
    {
        return $pincode->user_id == user_id() && $pincode->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Pincode $pincode)
    {
        if ($user->canDo('shipping.pincode.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given pincode.
     *
     * @param UserPolicy $user
     * @param Pincode $pincode
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Pincode $pincode)
    {
        if ($user->canDo('shipping.pincode.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
