<?php

namespace Shopping\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Shipping\Models\ShippingMethod;

class ShippingMethodPolicy
{

    /**
     * Determine if the given user can view the shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function view(UserPolicy $user, ShippingMethod $shipping_method)
    {
        if ($user->canDo('shipping.shipping_method.view') && $user->isAdmin()) {
            return true;
        }

        return $shipping_method->user_id == user_id() && $shipping_method->user_type == user_type();
    }

    /**
     * Determine if the given user can create a shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.shipping_method.create');
    }

    /**
     * Determine if the given user can update the given shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function update(UserPolicy $user, ShippingMethod $shipping_method)
    {
        if ($user->canDo('shipping.shipping_method.edit') && $user->isAdmin()) {
            return true;
        }

        return $shipping_method->user_id == user_id() && $shipping_method->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ShippingMethod $shipping_method)
    {
        return $shipping_method->user_id == user_id() && $shipping_method->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ShippingMethod $shipping_method)
    {
        if ($user->canDo('shipping.shipping_method.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given shipping_method.
     *
     * @param UserPolicy $user
     * @param ShippingMethod $shipping_method
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ShippingMethod $shipping_method)
    {
        if ($user->canDo('shipping.shipping_method.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
