<?php

namespace Shopping\Shipping\Policies;

use Litepie\User\Contracts\UserPolicy;
use Shopping\Shipping\Models\State;

class StatePolicy
{

    /**
     * Determine if the given user can view the state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function view(UserPolicy $user, State $state)
    {
        if ($user->canDo('shipping.state.view') && $user->isAdmin()) {
            return true;
        }

        return $state->user_id == user_id() && $state->user_type == user_type();
    }

    /**
     * Determine if the given user can create a state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('shipping.state.create');
    }

    /**
     * Determine if the given user can update the given state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function update(UserPolicy $user, State $state)
    {
        if ($user->canDo('shipping.state.edit') && $user->isAdmin()) {
            return true;
        }

        return $state->user_id == user_id() && $state->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, State $state)
    {
        return $state->user_id == user_id() && $state->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function verify(UserPolicy $user, State $state)
    {
        if ($user->canDo('shipping.state.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given state.
     *
     * @param UserPolicy $user
     * @param State $state
     *
     * @return bool
     */
    public function approve(UserPolicy $user, State $state)
    {
        if ($user->canDo('shipping.state.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
