<?php

namespace Shopping\Shipping\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Shopping\Shipping\Models\Shipping;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Shopping\Shipping\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/shipping/shipping_method/*')) {
            Route::bind('shipping_method', function ($shipping_method) {
                $shipping_methodrepo = $this->app->make('Shopping\Shipping\Interfaces\ShippingMethodRepositoryInterface');
                return $shipping_methodrepo->findorNew($shipping_method);
            });
        }

        if (Request::is('*/shipping/pincode/*')) {
            Route::bind('pincode', function ($pincode) {
                $pincoderepo = $this->app->make('Shopping\Shipping\Interfaces\PincodeRepositoryInterface');
                return $pincoderepo->findorNew($pincode);
            });
        }

        if (Request::is('*/shipping/country/*')) {
            Route::bind('country', function ($country) {
                $countryrepo = $this->app->make('Shopping\Shipping\Interfaces\CountryRepositoryInterface');
                return $countryrepo->findorNew($country);
            });
        }

        if (Request::is('*/shipping/state/*')) {
            Route::bind('state', function ($state) {
                $staterepo = $this->app->make('Shopping\Shipping\Interfaces\StateRepositoryInterface');
                return $staterepo->findorNew($state);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();

        $this->mapApiRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {
        if (request()->segment(1) == 'api' || request()->segment(2) == 'api') {
            return;
        }
        
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale(),
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

    /**
     * Define the "api" routes for the package.
     *
     * These routes are typically stateless.
     *
     * @return void
     */
    protected function mapApiRoutes()
    {
        if(request()->segment(1) != 'api' && request()->segment(2) != 'api') {
            return;
        }

        Route::group([
            'middleware' => 'api',
            'namespace'  => $this->namespace,
            'prefix'     => trans_setlocale() . '/api',
        ], function ($router) {
            require (__DIR__ . '/../../routes/api.php');
        });
    }

}
